@@ -156,6 +156,7 @@ class Production(metaclass=PoolMeta):
         Return the value of the production request.
         """
         pool = Pool()
+        UoM = pool.get('product.uom')
         Date = pool.get('ir.date')
         with Transaction().set_context(company=company.id):
             today = Date.today()
@@ -163,7 +164,17 @@ class Production(metaclass=PoolMeta):
             date = today
         else:
             date -= datetime.timedelta(1)
+        pbom = product.boms[0] if product.boms else None
         unit = product.default_uom
+        if pbom:
+            for output in pbom.bom.outputs:
+                if output.product == product:
+                    # Use output unit to ensure the quantity requested is
+                    # not floored to 0
+                    unit = output.unit
+                    quantity = UoM.compute_qty(
+                        product.default_uom, quantity, unit, round=False)
+                    break
         quantity = unit.ceil(quantity)
         if order_point:
             origin = str(order_point)
@@ -175,7 +186,7 @@ class Production(metaclass=PoolMeta):
             warehouse=warehouse,
             location=warehouse.production_location,
             product=product,
-            bom=product.boms[0].bom if product.boms else None,
+            bom=pbom.bom if pbom else None,
             unit=unit,
             quantity=quantity,
             state='request',
